Cassiny-CLI
========================
.. image:: https://pyup.io/repos/github/cassinyio/cassiny-cli/shield.svg
     :target: https://pyup.io/repos/github/cassinyio/cassiny-cli/
     :alt: Updates

.. image:: https://pyup.io/repos/github/cassinyio/cassiny-cli/python-3-shield.svg
     :target: https://pyup.io/repos/github/cassinyio/cassiny-cli/
     :alt: Python 3

.. image:: https://travis-ci.org/cassinyio/cassiny-cli.svg?branch=master
    :target: https://travis-ci.org/cassinyio/cassiny-cli

.. image:: https://codecov.io/gh/cassinyio/cassiny-cli/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/cassinyio/cassiny-cli

A CLI to interact with Cassiny's server.